@@ -20,20 +20,17 @@ fn copy_test_data(dir: &str) {
     // First remove the existing directory - just incase it is there and has incorrect data
     let last_slash = dir.rfind('/').unwrap();
     let last_part_of_dir = dir.chars().skip(last_slash).collect::<String>();
-    match Command::new("rm")
+    let _ = Command::new("rm")
         .arg("-rf")
         .arg("/tmp/".to_owned() + &*last_part_of_dir)
+        .ok();
+
+    let _ = Command::new("cp")
+        .arg("-r")
+        .arg(dir)
+        .arg("/tmp/")
         .ok()
-    {
-        Ok(_) => {}
-        Err(_) => {}
-    };
-    match Command::new("cp").arg("-r").arg(dir).arg("/tmp/").ok() {
-        Ok(_) => {}
-        Err(err) => {
-            eprintln!("Error copying directory {:?}", err);
-        }
-    };
+        .map_err(|err| eprintln!("Error copying directory for test setup\n{:?}", err));
 }
 
 fn initialize() {
@@ -48,14 +45,14 @@ fn exact_output_test<T: AsRef<OsStr>>(valid_outputs: Vec<String>, command_args:
     initialize();
 
     let mut a = &mut Command::cargo_bin("dust").unwrap();
+
     for p in command_args {
         a = a.arg(p);
     }
-    let output: String = str::from_utf8(&a.unwrap().stdout).unwrap().into();
 
-    assert!(valid_outputs
-        .iter()
-        .fold(false, |sum, i| sum || output.contains(i)));
+    let output = str::from_utf8(&a.unwrap().stdout).unwrap().to_owned();
+
+    assert!(valid_outputs.iter().any(|i| output.contains(i)));
 }
 
 // "windows" result data can vary by host (size seems to be variable by one byte); fix code vs test and re-enable
@@ -82,19 +79,19 @@ fn main_output() -> Vec<String> {
     // Some linux currently thought to be Manjaro, Arch
     // Although probably depends on how drive is formatted
     let mac_and_some_linux = r#"
-   0B     ┌── a_file    │░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
- 4.0K     ├── hello_file│████████████████████████████████████████████████ │ 100%
- 4.0K   ┌─┴ many        │████████████████████████████████████████████████ │ 100%
- 4.0K ┌─┴ test_dir      │████████████████████████████████████████████████ │ 100%
- "#
+  0B     ┌── a_file    │░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
+4.0K     ├── hello_file│█████████████████████████████████████████████████ │ 100%
+4.0K   ┌─┴ many        │█████████████████████████████████████████████████ │ 100%
+4.0K ┌─┴ test_dir      │█████████████████████████████████████████████████ │ 100%
+"#
     .trim()
     .to_string();
 
     let ubuntu = r#"
-   0B     ┌── a_file    │               ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
- 4.0K     ├── hello_file│               ░░░░░░░░░░░░░░░░█████████████████ │  33%
- 8.0K   ┌─┴ many        │               █████████████████████████████████ │  67%
-  12K ┌─┴ test_dir      │████████████████████████████████████████████████ │ 100%
+  0B     ┌── a_file    │                ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
+4.0K     ├── hello_file│                ░░░░░░░░░░░░░░░░█████████████████ │  33%
+8.0K   ┌─┴ many        │                █████████████████████████████████ │  67%
+ 12K ┌─┴ test_dir      │█████████████████████████████████████████████████ │ 100%
   "#
     .trim()
     .to_string();
@@ -111,25 +108,25 @@ pub fn test_main_long_paths() {
 
 fn main_output_long_paths() -> Vec<String> {
     let mac_and_some_linux = r#"
-   0B     ┌── /tmp/test_dir/many/a_file    │░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
- 4.0K     ├── /tmp/test_dir/many/hello_file│█████████████████████████████ │ 100%
- 4.0K   ┌─┴ /tmp/test_dir/many             │█████████████████████████████ │ 100%
- 4.0K ┌─┴ /tmp/test_dir                    │█████████████████████████████ │ 100%
+  0B     ┌── /tmp/test_dir/many/a_file    │░░░░░░░░░░░░░░░░░░░░░░░░░░░░░█ │   0%
+4.0K     ├── /tmp/test_dir/many/hello_file│██████████████████████████████ │ 100%
+4.0K   ┌─┴ /tmp/test_dir/many             │██████████████████████████████ │ 100%
+4.0K ┌─┴ /tmp/test_dir                    │██████████████████████████████ │ 100%
 "#
     .trim()
     .to_string();
     let ubuntu = r#"
-   0B     ┌── /tmp/test_dir/many/a_file    │         ░░░░░░░░░░░░░░░░░░░█ │   0%
- 4.0K     ├── /tmp/test_dir/many/hello_file│         ░░░░░░░░░░██████████ │  33%
- 8.0K   ┌─┴ /tmp/test_dir/many             │         ████████████████████ │  67%
-  12K ┌─┴ /tmp/test_dir                    │█████████████████████████████ │ 100%
+  0B     ┌── /tmp/test_dir/many/a_file    │         ░░░░░░░░░░░░░░░░░░░░█ │   0%
+4.0K     ├── /tmp/test_dir/many/hello_file│         ░░░░░░░░░░███████████ │  33%
+8.0K   ┌─┴ /tmp/test_dir/many             │         █████████████████████ │  67%
+ 12K ┌─┴ /tmp/test_dir                    │██████████████████████████████ │ 100%
 "#
     .trim()
     .to_string();
     vec![mac_and_some_linux, ubuntu]
 }
 
-// Check against directories and files whos names are substrings of each other
+// Check against directories and files whose names are substrings of each other
 #[cfg_attr(target_os = "windows", ignore)]
 #[test]
 pub fn test_substring_of_names_and_long_names() {
@@ -139,25 +136,25 @@ pub fn test_substring_of_names_and_long_names() {
 
 fn no_substring_of_names_output() -> Vec<String> {
     let ubuntu = "
-   0B   ┌── long_dir_name_what_a_very_long_dir_name_what_happens_when_this_goe..
- 4.0K   ├── dir_name_clash
- 4.0K   │ ┌── hello
- 8.0K   ├─┴ dir
- 4.0K   │ ┌── hello
- 8.0K   ├─┴ dir_substring
-  24K ┌─┴ test_dir2
+  0B   ┌── long_dir_name_what_a_very_long_dir_name_what_happens_when_this_goes..
+4.0K   ├── dir_name_clash
+4.0K   │ ┌── hello
+8.0K   ├─┴ dir
+4.0K   │ ┌── hello
+8.0K   ├─┴ dir_substring
+ 24K ┌─┴ test_dir2
     "
     .trim()
     .into();
 
     let mac_and_some_linux = "
-   0B   ┌── long_dir_name_what_a_very_long_dir_name_what_happens_when_this_goe..
- 4.0K   │ ┌── hello
- 4.0K   ├─┴ dir
- 4.0K   ├── dir_name_clash
- 4.0K   │ ┌── hello
- 4.0K   ├─┴ dir_substring
-  12K ┌─┴ test_dir2
+  0B   ┌── long_dir_name_what_a_very_long_dir_name_what_happens_when_this_goes..
+4.0K   │ ┌── hello
+4.0K   ├─┴ dir
+4.0K   ├── dir_name_clash
+4.0K   │ ┌── hello
+4.0K   ├─┴ dir_substring
+ 12K ┌─┴ test_dir2
   "
     .trim()
     .into();
@@ -174,17 +171,17 @@ pub fn test_unicode_directories() {
 fn unicode_dir() -> Vec<String> {
     // The way unicode & asian characters are rendered on the terminal should make this line up
     let ubuntu = "
-   0B   ┌── ラウトは難しいです！.japan│                                 █ │   0%
-   0B   ├── 👩.unicode                │                                 █ │   0%
- 4.0K ┌─┴ test_dir_unicode            │██████████████████████████████████ │ 100%
+  0B   ┌── ラウトは難しいです！.japan│                                  █ │   0%
+  0B   ├── 👩.unicode                │                                  █ │   0%
+4.0K ┌─┴ test_dir_unicode            │███████████████████████████████████ │ 100%
     "
     .trim()
     .into();
 
     let mac_and_some_linux = "
-   0B   ┌── ラウトは難しいです！.japan│                                 █ │   0%
-   0B   ├── 👩.unicode                │                                 █ │   0%
-   0B ┌─┴ test_dir_unicode            │                                 █ │   0%
+0B   ┌── ラウトは難しいです！.japan│                                    █ │   0%
+0B   ├── 👩.unicode                │                                    █ │   0%
+0B ┌─┴ test_dir_unicode            │                                    █ │   0%
     "
     .trim()
     .into();
@@ -201,8 +198,8 @@ pub fn test_apparent_size() {
 fn apparent_size_output() -> Vec<String> {
     // The apparent directory sizes are too unpredictable and system dependant to try and match
     let files = r#"
-   0B     ┌── a_file
-   6B     ├── hello_file
+  0B     ┌── a_file
+  6B     ├── hello_file
  "#
     .trim()
     .to_string();
