@@ -9,11 +9,15 @@ use std::str;
  */
 
 fn build_command<T: AsRef<OsStr>>(command_args: Vec<T>) -> String {
-    let mut a = &mut Command::cargo_bin("dust").unwrap();
+    let mut cmd = &mut Command::cargo_bin("dust").unwrap();
     for p in command_args {
-        a = a.arg(p);
+        cmd = cmd.arg(p);
     }
-    str::from_utf8(&a.unwrap().stdout).unwrap().into()
+    let finished = &cmd.unwrap();
+    let stderr = str::from_utf8(&finished.stderr).unwrap();
+    assert_eq!(stderr, "");
+
+    str::from_utf8(&finished.stdout).unwrap().into()
 }
 
 // We can at least test the file names are there
@@ -63,7 +67,7 @@ pub fn test_d_flag_works_and_still_recurses_down() {
     assert!(output.contains("4 ┌─┴ test_dir2"));
 }
 
-// Check against directories and files whos names are substrings of each other
+// Check against directories and files whose names are substrings of each other
 #[test]
 pub fn test_ignore_dir() {
     let output = build_command(vec!["-c", "-X", "dir_substring", "tests/test_dir2/"]);
@@ -73,8 +77,8 @@ pub fn test_ignore_dir() {
 #[test]
 pub fn test_with_bad_param() {
     let mut cmd = Command::cargo_bin("dust").unwrap();
-    let stderr = cmd.arg("-").unwrap().stderr;
-    let stderr = str::from_utf8(&stderr).unwrap();
+    let result = cmd.arg("bad_place").unwrap();
+    let stderr = str::from_utf8(&result.stderr).unwrap();
     assert!(stderr.contains("Did not have permissions for all directories"));
 }
 
@@ -112,6 +116,17 @@ pub fn test_show_files_by_type() {
     assert!(output.contains("┌─┴ (total)"));
 }
 
+#[test]
+pub fn test_output_skip_total() {
+    let output = build_command(vec![
+        "--skip-total",
+        "tests/test_dir/many/hello_file",
+        "tests/test_dir/many/a_file",
+    ]);
+    assert!(output.contains("hello_file"));
+    assert!(!output.contains("(total)"));
+}
+
 #[test]
 pub fn test_show_files_by_regex_match_lots() {
     // Check we can see '.rs' files in the tests directory
